@@ -12,6 +12,7 @@ import (
 	proxyinformersv1 "github.com/openshift/client-go/config/informers/externalversions/config/v1"
 	operatorclientv1 "github.com/openshift/client-go/operator/clientset/versioned/typed/operator/v1"
 	operatorinformersv1 "github.com/openshift/client-go/operator/informers/externalversions/operator/v1"
+	"github.com/openshift/cluster-svcat-controller-manager-operator/pkg/metrics"
 	"github.com/openshift/cluster-svcat-controller-manager-operator/pkg/util"
 	"github.com/openshift/library-go/pkg/operator/events"
 	"github.com/openshift/library-go/pkg/operator/v1helpers"
@@ -110,6 +111,13 @@ func (c ServiceCatalogControllerManagerOperator) sync() error {
 		}
 	}
 
+	v1helpers.SetOperatorCondition(&operatorConfig.Status.Conditions, operatorapiv1.OperatorCondition{
+		Type:    operatorapiv1.OperatorStatusTypeUpgradeable,
+		Status:  operatorapiv1.ConditionTrue,
+		Reason:  "",
+		Message: "",
+	})
+
 	switch operatorConfig.Spec.ManagementState {
 	case operatorapiv1.Managed:
 		// redundant but it makes reading this switch later more clear
@@ -141,6 +149,7 @@ func (c ServiceCatalogControllerManagerOperator) sync() error {
 				return err
 			}
 		}
+		metrics.ControllerManagerDisabled()
 		return nil
 
 	case operatorapiv1.Removed:
@@ -154,13 +163,13 @@ func (c ServiceCatalogControllerManagerOperator) sync() error {
 			Type:    operatorapiv1.OperatorStatusTypeAvailable,
 			Status:  operatorapiv1.ConditionTrue,
 			Reason:  "Removed",
-			Message: "",
+			Message: "the controller manager is not initially installed, operator is available, switch to Managed to enable.",
 		})
 		v1helpers.SetOperatorCondition(&operatorConfig.Status.Conditions, operatorapiv1.OperatorCondition{
 			Type:    operatorapiv1.OperatorStatusTypeProgressing,
 			Status:  operatorapiv1.ConditionFalse,
 			Reason:  "Removed",
-			Message: "",
+			Message: "the controller manager is in a removed state, therefore no changes are being applied.",
 		})
 		v1helpers.SetOperatorCondition(&operatorConfig.Status.Conditions, operatorapiv1.OperatorCondition{
 			Type:    operatorapiv1.OperatorStatusTypeDegraded,
@@ -177,6 +186,7 @@ func (c ServiceCatalogControllerManagerOperator) sync() error {
 				return err
 			}
 		}
+		metrics.ControllerManagerDisabled()
 		return nil
 
 	default:
@@ -184,6 +194,7 @@ func (c ServiceCatalogControllerManagerOperator) sync() error {
 		return nil
 	}
 
+	metrics.ControllerManagerEnabled()
 	forceRequeue, err := syncServiceCatalogControllerManager_v311_00_to_latest(c, operatorConfig, proxyConfig)
 	if forceRequeue && err != nil {
 		c.queue.AddRateLimited(workQueueKey)
